"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@testing-library/react");
const Field_1 = tslib_1.__importDefault(require("../Field"));
const Form_1 = tslib_1.__importDefault(require("../Form"));
const Object_1 = tslib_1.__importDefault(require("../Object"));
const index_1 = tslib_1.__importDefault(require("./index"));
require("@testing-library/jest-dom");
const react_2 = require("react");
jest.useFakeTimers();
function DummyInput(props) {
    return ((0, jsx_runtime_1.jsx)("input", { name: props.fieldName, className: "test-input", value: props.value || '', onChange: event => {
            props.onChange(event.target.value);
        } }));
}
it('should render correctly', () => {
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "array", type: index_1.default }) }));
    expect(container.querySelector('.srf-array-container')).toBeInTheDocument();
});
it('addItem should add an item', () => {
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "array", type: index_1.default, children: (0, jsx_runtime_1.jsx)("div", { className: "children" }) }) }));
    expect(container.querySelector('.children')).not.toBeInTheDocument();
    react_1.fireEvent.click(react_1.screen.getByText('Add'));
    expect(container.querySelector('.children')).toBeInTheDocument();
});
it('removeItem should remove the item', () => {
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "array", type: index_1.default, children: (0, jsx_runtime_1.jsx)("div", { className: "children" }) }) }));
    react_1.fireEvent.click(react_1.screen.getByText('Add'));
    expect(container.querySelector('.children')).toBeInTheDocument();
    react_1.fireEvent.click(react_1.screen.getByText('Remove'));
    expect(container.querySelector('.children')).not.toBeInTheDocument();
});
it('should render an error if there is one', () => {
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "array", type: index_1.default, errorMessage: "I AM AN ERROR" }) }));
    expect(container.querySelector('.srf_errorMessage')).toBeInTheDocument();
});
it('should pass the value to the child fields', () => {
    const item = { name: 'hello', text: 'bye' };
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { state: { items: [item] }, children: (0, jsx_runtime_1.jsxs)(Field_1.default, { fieldName: "items", type: index_1.default, children: [(0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }), (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "text", type: DummyInput })] }) }));
    expect(container.getElementsByTagName('input')[0].value).toBe('hello');
    expect(container.getElementsByTagName('input')[1].value).toBe('bye');
});
test('onChange should make changes correctly', async () => {
    let state = { persons: [{ name: 'Nicolás' }] };
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { state: state, onChange: changes => {
            state = changes;
        }, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "persons", type: index_1.default, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }) }) }));
    (0, react_2.act)(() => {
        react_1.fireEvent.change(container.querySelector('.test-input'), { target: { value: 'Joaquín' } });
        jest.advanceTimersByTime(0);
    });
    expect(state).toEqual({ persons: [{ name: 'Joaquín' }] });
});
test('onChange should make changes correctly on double array', () => {
    let state = {
        person: {
            friends: [{ name: 'Nicolás' }],
        },
    };
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { state: state, onChange: changes => {
            state = changes;
        }, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "person", type: Object_1.default, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "friends", type: index_1.default, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }) }) }) }));
    (0, react_2.act)(() => {
        react_1.fireEvent.change(container.querySelector('input'), { target: { value: 'Joaquín' } });
        jest.advanceTimersByTime(0);
    });
    expect(state).toEqual({
        person: {
            friends: [{ name: 'Joaquín' }],
        },
    });
});
//# sourceMappingURL=index.test.js.map