"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@testing-library/react");
const react_2 = tslib_1.__importStar(require("react"));
const Field_1 = tslib_1.__importDefault(require("../Field"));
const Form_1 = tslib_1.__importDefault(require("../Form"));
require("@testing-library/jest-dom");
jest.useFakeTimers();
test('should call focus on child', () => {
    let didCall = false;
    let field = null;
    class DummyInput extends react_2.default.Component {
        focus() {
            didCall = true;
        }
        render() {
            return (0, jsx_runtime_1.jsx)("input", { className: "input", type: "text" });
        }
    }
    (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { children: (0, jsx_runtime_1.jsx)(Field_1.default, { ref: handle => {
                field = handle;
            }, fieldName: "name", type: DummyInput }) }));
    field.focus();
    expect(didCall).toBe(true);
});
test('should pass parent value', () => {
    let checked = false;
    function DummyInput(props) {
        checked = true;
        expect(props.parentValue).toEqual({ hello: 'world' });
        return (0, jsx_runtime_1.jsx)("div", {});
    }
    (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { state: { hello: 'world' }, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }) }));
    expect(checked).toBe(true);
});
test('should inherit field type props', () => {
    function DummyInput(_props) {
        return (0, jsx_runtime_1.jsx)("div", {});
    }
    (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { state: { hello: 'world' }, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "hello", type: DummyInput, name: "ss2ss" }) }));
});
test('should be able to add any prop to the field', () => {
    let checked = false;
    function DummyInput(props) {
        checked = true;
        expect(props.parentValue).toEqual({ hello: 'world' });
        return (0, jsx_runtime_1.jsx)("div", { children: "dummy" });
    }
    (0, react_1.render)((0, jsx_runtime_1.jsx)(Form_1.default, { state: { hello: 'world' }, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput, passingProp: 100 }) }));
    expect(checked).toBe(true);
});
test('should allow using nested field with onChange', async () => {
    function HelloInput(props) {
        return ((0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: (0, jsx_runtime_1.jsx)("input", { value: props.value, onChange: event => props.onChange(event.target.value), placeholder: "hello", className: "input", type: "text" }) }));
    }
    function ItemsInput(props) {
        return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)("button", { type: "button", onClick: () => {
                        props.onChange(oldVal => {
                            return [...oldVal, { hello: oldVal.length }];
                        });
                    }, children: "add" }), props.value.map((_item, index) => {
                    return (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: String(`${index}.hello`), type: HelloInput }, index);
                })] }));
    }
    let testValue = null;
    function Test() {
        const [state, setState] = (0, react_2.useState)({ items: [] });
        testValue = state;
        return ((0, jsx_runtime_1.jsx)(Form_1.default, { state: state, onChange: setState, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "items", type: ItemsInput }) }));
    }
    (0, react_1.render)((0, jsx_runtime_1.jsx)(Test, {}));
    await (0, react_2.act)(async () => {
        react_1.fireEvent.click(react_1.screen.getByText('add'));
        jest.advanceTimersByTime(0);
    });
    await (0, react_2.act)(async () => {
        react_1.fireEvent.change(react_1.screen.getByPlaceholderText('hello'), { target: { value: 'no' } });
        jest.advanceTimersByTime(0);
    });
    await (0, react_2.act)(async () => {
        react_1.fireEvent.click(react_1.screen.getByText('add'));
        jest.advanceTimersByTime(0);
    });
    await (0, react_2.act)(async () => {
        react_1.fireEvent.click(react_1.screen.getByText('add'));
        jest.advanceTimersByTime(0);
    });
    await (0, react_2.act)(async () => {
        react_1.fireEvent.click(react_1.screen.getByText('add'));
        jest.advanceTimersByTime(0);
    });
    expect(testValue).toEqual({ items: [{ hello: 'no' }, { hello: 1 }, { hello: 2 }, { hello: 3 }] });
});
test('should allow using nested array field', async () => {
    function HelloInput(props) {
        return ((0, jsx_runtime_1.jsx)("input", { value: props.value || '', onChange: event => props.onChange(event.target.value), placeholder: props.fieldName, className: "input", type: "text" }));
    }
    function InterInput(_props) {
        return (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "hello", type: HelloInput });
    }
    let testValue = null;
    function Test() {
        const [state, setState] = (0, react_2.useState)({});
        testValue = state;
        return ((0, jsx_runtime_1.jsxs)(Form_1.default, { state: state, onChange: newVal => {
                setState(newVal);
            }, children: [(0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "items.0", type: InterInput }), (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "items.1", type: InterInput })] }));
    }
    (0, react_1.render)((0, jsx_runtime_1.jsx)(Test, {}));
    (0, react_2.act)(() => {
        react_1.fireEvent.change(react_1.screen.getByPlaceholderText('items.0.hello'), { target: { value: 'no0' } });
        react_1.fireEvent.change(react_1.screen.getByPlaceholderText('items.1.hello'), { target: { value: 'no1' } });
        jest.advanceTimersByTime(100);
    });
    expect(testValue).toEqual({ items: [{ hello: 'no0' }, { hello: 'no1' }] });
});
test('adding items to array very fast should be handled correctly', async () => {
    function ItemsInput(props) {
        return ((0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: (0, jsx_runtime_1.jsx)("button", { type: "button", onClick: () => props.onChange(oldVal => [...oldVal, { hello: oldVal.length }]), children: "add" }) }));
    }
    let testValue = null;
    function Test() {
        const [state, setState] = (0, react_2.useState)({ items: [] });
        testValue = state;
        return ((0, jsx_runtime_1.jsx)(Form_1.default, { state: state, onChange: setState, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "items", type: ItemsInput }) }));
    }
    (0, react_1.render)((0, jsx_runtime_1.jsx)(Test, {}));
    await (0, react_2.act)(async () => {
        react_1.fireEvent.click(react_1.screen.getByText('add'));
        react_1.fireEvent.click(react_1.screen.getByText('add'));
        react_1.fireEvent.click(react_1.screen.getByText('add'));
        jest.advanceTimersByTime(0);
    });
    expect(testValue).toEqual({ items: [{ hello: 0 }, { hello: 1 }, { hello: 2 }] });
});
//# sourceMappingURL=index.test.js.map