"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@testing-library/react");
const Field_1 = tslib_1.__importDefault(require("../Field"));
const Object_1 = tslib_1.__importDefault(require("../Object"));
const index_1 = tslib_1.__importDefault(require("./index"));
require("@testing-library/jest-dom");
const react_2 = require("react");
jest.useFakeTimers();
function DummyInput(props) {
    return ((0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsx)("div", { className: "errorMessage", children: props.errorMessage }), (0, jsx_runtime_1.jsx)("input", { value: props.value || '', onChange: event => {
                    props.onChange(event.target.value);
                } })] }));
}
test('Should render by default a <form>', () => {
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { children: (0, jsx_runtime_1.jsx)("div", { children: "dummy" }) }));
    expect(container.querySelector('form')).toBeInTheDocument();
});
test('Should not render a <form> if useFormTag is false', () => {
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { useFormTag: false, children: (0, jsx_runtime_1.jsx)("div", { children: "dummy" }) }));
    expect(container.querySelector('form')).not.toBeInTheDocument();
});
test('onChange should dispatch on changes', async () => {
    const mockFn = jest.fn();
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { onChange: mockFn, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "foo", type: DummyInput }) }));
    await (0, react_2.act)(async () => {
        react_1.fireEvent.change(container.querySelector('input'), { target: { value: 'foobar' } });
        jest.advanceTimersByTime(0);
    });
    expect(mockFn.mock.calls[0][0]).toEqual({ foo: 'foobar' });
    await (0, react_2.act)(async () => {
        react_1.fireEvent.change(container.querySelector('input'), { target: { value: 'barfoo' } });
        jest.advanceTimersByTime(0);
    });
    expect(mockFn.mock.calls[1][0]).toEqual({ foo: 'barfoo' });
});
it('should render the form correctly', () => {
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "foo", type: DummyInput }) }));
    expect(container.querySelector('form')).toBeInTheDocument();
    expect(container.querySelector('input')).toBeInTheDocument();
});
test('passes the errorMessage correctly', () => {
    const errorMessages = {
        'person.name': 'Error',
    };
    (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { errorMessages: errorMessages, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "person", type: Object_1.default, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }) }) }));
    expect(react_1.screen.getByText(errorMessages['person.name'])).toBeInTheDocument();
});
test('allows calling on submit using ref', () => {
    let form = null;
    const mockFn = jest.fn();
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { ref: handle => {
            form = handle;
        }, onSubmit: mockFn, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }) }));
    react_1.fireEvent.change(container.querySelector('input'), { target: { value: 'Nicolás' } });
    react_1.fireEvent.submit(container.querySelector('form'));
    react_1.fireEvent.change(container.querySelector('input'), { target: { value: 'Nico' } });
    form.submit();
    expect(mockFn.mock.calls[0][0]).toEqual({ name: 'Nicolás' });
    expect(mockFn.mock.calls[1][0]).toEqual({ name: 'Nico' });
});
test('test form html props', () => {
    (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { target: "/hello", children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }) }));
});
test('should allow to reset state', () => {
    let form = null;
    let state = {};
    const setState = newState => {
        state = newState;
    };
    const { container } = (0, react_1.render)((0, jsx_runtime_1.jsx)(index_1.default, { ref: handle => {
            form = handle;
        }, state: state, onChange: setState, children: (0, jsx_runtime_1.jsx)(Field_1.default, { fieldName: "name", type: DummyInput }) }));
    (0, react_2.act)(() => {
        react_1.fireEvent.change(container.querySelector('input'), { target: { value: 'Nicolás' } });
    });
    expect(form.getValue()).toEqual({ name: 'Nicolás' });
    (0, react_2.act)(() => {
        form.reset();
    });
    (0, react_2.act)(() => {
        react_1.fireEvent.change(container.querySelector('input'), { target: { value: 'Nico' } });
    });
    expect(form.getValue()).toEqual({ name: 'Nico' });
});
//# sourceMappingURL=index.test.js.map